@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,11 +11,11 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 
 def default_executor(function):  # pragma: nocover
@@ -33,6 +33,7 @@ def setup_teardown_executor(setup, teardown):
             return function()
         finally:
             teardown(token)
+
     return execute
 
 
@@ -42,13 +43,10 @@ def executor(runner):
     except AttributeError:
         pass
 
-    if (
-        hasattr(runner, 'setup_example') or
-        hasattr(runner, 'teardown_example')
-    ):
+    if hasattr(runner, "setup_example") or hasattr(runner, "teardown_example"):
         return setup_teardown_executor(
-            getattr(runner, 'setup_example', None),
-            getattr(runner, 'teardown_example', None),
+            getattr(runner, "setup_example", None),
+            getattr(runner, "teardown_example", None),
         )
 
     return default_executor
@@ -59,7 +57,6 @@ def default_new_style_executor(data, function):
 
 
 class ConjectureRunner(object):
-
     def hypothesis_execute_example_with_data(self, data, function):
         return function(data)
 
@@ -74,6 +71,4 @@ def new_style_executor(runner):
     if old_school is default_executor:
         return default_new_style_executor
     else:
-        return lambda data, function: old_school(
-            lambda: function(data)
-        )
+        return lambda data, function: old_school(lambda: function(data))
